@@ -4,7 +4,8 @@ Q <- MixSim(MaxOmega = 0.1, K = 4, p = 1)
 A <- simdataset(n = 300, Pi = Q$Pi, Mu = Q$Mu, S = Q$S, n.noise = 1)
 colors <- c("red", "green", "blue", "brown")
 
-plot(A$X, xlab = "", ylab = "", type = "n", axes = F)
 par(mar = c(0.1, 0.1, 0.1, 0.1))
+plot(A$X, col = colors[A$id], pch = 19, cex = 0.8, 
+     xlab = "", ylab = "", axes = FALSE)
 box()
-points(A$X, col = colors[A$id], pch = 19, cex = 0.8)
+
